Module authenticator

Module authenticator 

The Authenticator is the main component with which users interact with the World ID Protocol.

Modules

artifacts
Artifact sources & traits for loading/caching & managing ZK Artifacts

Structs

Authenticator
The Authenticator is the main component with which users interact with the World ID Protocol.
InitializingAuthenticator
Represents an Authenticator in the process of being initialized.
RecoveryData
Identity material derived from a seed for use during account recovery.
RecoveryUpdateSignature
The signature and signing nonce returned by Authenticator::danger_sign_initiate_recovery_agent_update.

Enums

GatewayRequestStatus
Status of an account operation submitted through the gateway.
RegistrationStatus
Registration status for a World ID being created through the gateway.

Functions

recovery_data_from_seed
Derives recovery data from a 32-byte seed.
validate_authenticator_pubkey
Validates an authenticator public key without submitting an account operation, returning its canonical encoding.