pub enum WalletKitError {
Show 33 variants
InvalidInput {
attribute: String,
reason: String,
},
InvalidNumber,
SerializationError {
error: String,
},
NetworkError {
url: String,
error: String,
status: Option<u16>,
},
Reqwest {
error: String,
},
ProofGeneration {
error: String,
},
SemaphoreNotEnabled,
CredentialNotIssued,
CredentialNotMined,
AccountDoesNotExist,
UnauthorizedAuthenticator,
AuthenticatorError {
error: String,
},
UnfulfillableRequest,
ResponseValidation(String),
NullifierReplay,
InvalidRpSignature,
DuplicateNonce,
UnknownRp,
InactiveRp,
TimestampTooOld,
TimestampTooFarInFuture,
InvalidTimestamp,
RpSignatureExpired,
Groth16MaterialCacheInvalid {
path: String,
error: String,
},
Groth16MaterialEmbeddedLoad {
error: String,
},
Generic {
error: String,
},
RecoveryBindingDoesNotExist,
SessionIdMismatch,
NfcNonRetryable {
error_code: String,
},
DebugReportNotFound,
NotEligibleForRecovery,
OhttpError {
error: String,
},
InvalidActionSession,
}Expand description
Error outputs from WalletKit
Variants
InvalidInput
Invalid input provided (e.g., incorrect length, format, etc.)
Fields
InvalidNumber
The presented data is not a valid U256 integer
SerializationError
Unexpected error serializing information
NetworkError
Network connection error with details
Fields
Reqwest
HTTP request failure
ProofGeneration
Unhandled error generating a Zero-Knowledge Proof
SemaphoreNotEnabled
The semaphore feature flag is not enabled
CredentialNotIssued
The requested credential is not issued for this World ID
CredentialNotMined
The requested credential has not been submitted on-chain
AccountDoesNotExist
This operation requires a registered account and an account is not registered
for this authenticator. Call create_account first to register it.
The public key was not found in the batch, i.e. the authenticator is not authorized to sign for this action
AuthenticatorError
An unexpected error occurred with the Authenticator
UnfulfillableRequest
The request could not be fulfilled with the credentials the user has available
ResponseValidation(String)
The response generated didn’t match the request
This occurs if the response doesn’t match the requested proofs - e.g. by ids or doesn’t satisfy the contraints declared in the request
NullifierReplay
The generated nullifier has already been used in a proof submission and cannot be used again
InvalidRpSignature
The RP’s signature on the proof request could not be verified.
DuplicateNonce
The RP reused a signature nonce.
UnknownRp
The RP is unknown to the World ID registry.
InactiveRp
The RP is inactive and cannot request proofs.
TimestampTooOld
The RP’s request timestamp is too old.
TimestampTooFarInFuture
The RP’s request timestamp is too far in the future.
InvalidTimestamp
The RP’s request timestamp could not be parsed.
RpSignatureExpired
The RP’s signature has expired.
Groth16MaterialCacheInvalid
Cached Groth16 material could not be parsed or verified.
Groth16MaterialEmbeddedLoad
Failed to load embedded Groth16 material.
Generic
An unexpected error occurred
RecoveryBindingDoesNotExist
The recovery binding does not exist
SessionIdMismatch
The session ID computed for this proof does not match the expected session ID from the proof request.
This indicates the session_id provided by the RP is invalid or compromised, as
the only other failure option is OPRFs not having performed correct computations.
NfcNonRetryable
The NFC uniqueness service rejected the request with a permanent error that will not resolve on retry (e.g. expired document).
DebugReportNotFound
The debug report was not found
NotEligibleForRecovery
The user is not eligible for recovery
OhttpError
An error occurred in the OHTTP privacy layer (relay, encapsulation, or framing).
InvalidActionSession
The session proof action or session OPRF seed is not valid for the session OPRF module.