pub struct RecoveryBinding {
pub recovery_agent: Option<String>,
pub pending_recovery_agent: Option<String>,
pub execute_after: Option<String>,
}Expand description
Represents a recovery binding.
Fields
recovery_agent: Option<String>The hex address of the recovery agent (e.g. "0x1234…").
pending_recovery_agent: Option<String>The hex address of the pending recovery agent (e.g. "0x1234…").
execute_after: Option<String>The timestamp of the recovery agent update in seconds since the Unix epoch.