pub struct StoragePaths { /* private fields */ }Expand description
Paths for credential storage artifacts under <root>/worldid.
Implementations
Sourceimpl StoragePaths
impl StoragePaths
Sourcepub fn worldid_dir(&self) -> &Path
pub fn worldid_dir(&self) -> &Path
Returns the World ID storage directory.
Sourcepub fn vault_db_path(&self) -> PathBuf
pub fn vault_db_path(&self) -> PathBuf
Returns the path to the vault database.
Sourcepub fn cache_db_path(&self) -> PathBuf
pub fn cache_db_path(&self) -> PathBuf
Returns the path to the cache database.
Sourcepub fn groth16_dir(&self) -> PathBuf
pub fn groth16_dir(&self) -> PathBuf
Returns the path to the Groth16 material directory.
Sourcepub fn query_zkey_path(&self) -> PathBuf
pub fn query_zkey_path(&self) -> PathBuf
Returns the path to the query zkey file.
Sourcepub fn nullifier_zkey_path(&self) -> PathBuf
pub fn nullifier_zkey_path(&self) -> PathBuf
Returns the path to the nullifier zkey file.
Sourcepub fn query_graph_path(&self) -> PathBuf
pub fn query_graph_path(&self) -> PathBuf
Returns the path to the query graph file.
Sourcepub fn nullifier_graph_path(&self) -> PathBuf
pub fn nullifier_graph_path(&self) -> PathBuf
Returns the path to the nullifier graph file.
Sourceimpl StoragePaths
impl StoragePaths
Sourcepub fn root_path_string(&self) -> String
pub fn root_path_string(&self) -> String
Returns the storage root directory as a string.
Sourcepub fn worldid_dir_path_string(&self) -> String
pub fn worldid_dir_path_string(&self) -> String
Returns the World ID storage directory as a string.
Sourcepub fn vault_db_path_string(&self) -> String
pub fn vault_db_path_string(&self) -> String
Returns the path to the vault database as a string.
Sourcepub fn cache_db_path_string(&self) -> String
pub fn cache_db_path_string(&self) -> String
Returns the path to the cache database as a string.
Sourcepub fn lock_path_string(&self) -> String
pub fn lock_path_string(&self) -> String
Returns the path to the lock file as a string.
Sourcepub fn groth16_dir_path_string(&self) -> String
pub fn groth16_dir_path_string(&self) -> String
Returns the path to the Groth16 material directory as a string.
Sourcepub fn query_zkey_path_string(&self) -> String
pub fn query_zkey_path_string(&self) -> String
Returns the path to the query zkey file as a string.
Sourcepub fn nullifier_zkey_path_string(&self) -> String
pub fn nullifier_zkey_path_string(&self) -> String
Returns the path to the nullifier zkey file as a string.
Sourcepub fn query_graph_path_string(&self) -> String
pub fn query_graph_path_string(&self) -> String
Returns the path to the query graph file as a string.
Sourcepub fn nullifier_graph_path_string(&self) -> String
pub fn nullifier_graph_path_string(&self) -> String
Returns the path to the nullifier graph file as a string.