pub struct InitializingAuthenticator(/* private fields */);Expand description
Represents an Authenticator in the process of being initialized.
The account is not yet registered in the WorldIDRegistry contract.
Use this for non-blocking registration flows where you want to poll the status yourself.
Implementations
Sourceimpl InitializingAuthenticator
impl InitializingAuthenticator
Sourcepub async fn register_with_defaults(
seed: &[u8],
rpc_url: Option<String>,
environment: &Environment,
region: Option<Region>,
recovery_address: Option<String>,
) -> Result<Self, WalletKitError>
pub async fn register_with_defaults( seed: &[u8], rpc_url: Option<String>, environment: &Environment, region: Option<Region>, recovery_address: Option<String>, ) -> Result<Self, WalletKitError>
Registers a new World ID with SDK defaults.
This returns immediately and does not wait for registration to complete.
The returned InitializingAuthenticator can be used to poll the registration status.
Errors
See CoreAuthenticator::register for potential errors.
Sourcepub async fn register(
seed: &[u8],
config: &str,
recovery_address: Option<String>,
) -> Result<Self, WalletKitError>
pub async fn register( seed: &[u8], config: &str, recovery_address: Option<String>, ) -> Result<Self, WalletKitError>
Registers a new World ID.
This returns immediately and does not wait for registration to complete.
The returned InitializingAuthenticator can be used to poll the registration status.
Errors
See CoreAuthenticator::register for potential errors.
Sourcepub async fn poll_status(&self) -> Result<RegistrationStatus, WalletKitError>
pub async fn poll_status(&self) -> Result<RegistrationStatus, WalletKitError>
Polls the registration status from the gateway.
Errors
Will error if the network request fails or the gateway returns an error.