The Authenticator is the main component with which users interact with the World ID Protocol.
Modules
- artifacts
- Artifact sources & traits for loading/caching & managing ZK Artifacts
Structs
- Authenticator
- The Authenticator is the main component with which users interact with the World ID Protocol.
- Initializing
Authenticator - Represents an Authenticator in the process of being initialized.
- Recovery
Data - Identity material derived from a seed for use during account recovery.
- Recovery
Update Signature - The signature and signing nonce returned by
Authenticator::danger_sign_initiate_recovery_agent_update.
Enums
- Gateway
Request Status - Status of an account operation submitted through the gateway.
- Registration
Status - Registration status for a World ID being created through the gateway.
Functions
- recovery_
data_ from_ seed - Derives recovery data from a 32-byte seed.
- validate_
authenticator_ pubkey - Validates an authenticator public key without submitting an account operation, returning its canonical encoding.