Authenticator

Struct Authenticator 

pub struct Authenticator { /* private fields */ }
The Authenticator is the main component with which users interact with the World ID Protocol.

Implementations

Source

impl Authenticator

pub fn init_storage(&self, now: u64) -> Result<(), WalletKitError>

Initializes storage using the authenticator’s leaf index.

Errors

Returns an error if the leaf index is invalid or storage initialization fails.

Source

impl Authenticator

pub fn packed_account_data(&self) -> U256Wrapper

Returns the packed account data for the holder’s World ID.

The packed account data is a 256 bit integer which includes the user’s leaf index, their recovery counter, and their pubkey id/commitment.

pub fn leaf_index(&self) -> u64

Returns the leaf index for the holder’s World ID.

This is the index in the Merkle tree where the holder’s World ID account is registered. It should only be used inside the authenticator and never shared.

pub fn onchain_address(&self) -> String

Returns the Authenticator’s onchain_address.

See world_id_core::Authenticator::onchain_address for more details.

pub async fn get_packed_account_data_remote( &self, ) -> Result<U256Wrapper, WalletKitError>

Returns the packed account data for the holder’s World ID fetching it from the on-chain registry.

Errors

Will error if the provided RPC URL is not valid or if there are RPC call failures.

pub async fn generate_credential_blinding_factor_remote( &self, issuer_schema_id: u64, ) -> Result<FieldElement, WalletKitError>

Generates a blinding factor for a Credential sub (through OPRF Nodes).

See CoreAuthenticator::generate_credential_blinding_factor for more details.

Errors
  • Will generally error if there are network issues or if the OPRF Nodes return an error.
  • Raises an error if the OPRF Nodes configuration is not correctly set.
pub fn compute_credential_sub( &self, blinding_factor: &FieldElement, ) -> FieldElement

Compute the sub for a credential from the authenticator’s leaf index and a blinding_factor.

Source

impl Authenticator

pub async fn init_with_defaults( seed: &[u8], rpc_url: Option<String>, environment: &Environment, region: Option<Region>, paths: Arc<StoragePaths>, store: Arc<CredentialStore>, ) -> Result<Self, WalletKitError>

Initializes a new Authenticator from a seed and with SDK defaults.

The user’s World ID must already be registered in the WorldIDRegistry, otherwise a WalletKitError::AccountDoesNotExist error will be returned.

Errors

See CoreAuthenticator::init for potential errors.

pub async fn init( seed: &[u8], config: &str, paths: Arc<StoragePaths>, store: Arc<CredentialStore>, ) -> Result<Self, WalletKitError>

Initializes a new Authenticator from a seed and config.

The user’s World ID must already be registered in the WorldIDRegistry, otherwise a WalletKitError::AccountDoesNotExist error will be returned.

Errors

Will error if the provided seed is not valid or if the config is not valid.

pub async fn generate_proof( &self, proof_request: &ProofRequest, now: Option<u64>, ) -> Result<ProofResponse, WalletKitError>

Generates a proof for the given proof request.

Errors

Returns an error if proof generation fails.