pub struct Credential(/* private fields */);Expand description
A wrapper around CoreCredential to enable FFI interoperability.
Encapsulates the credential and exposes accessors for fields that FFI callers need.
Implementations
Sourceimpl Credential
impl Credential
Sourcepub fn from_bytes(bytes: Vec<u8>) -> Result<Self, WalletKitError>
pub fn from_bytes(bytes: Vec<u8>) -> Result<Self, WalletKitError>
Deserializes a Credential from a JSON byte blob.
Errors
Returns an error if the bytes cannot be deserialized.
Sourcepub fn sub(&self) -> FieldElement
pub fn sub(&self) -> FieldElement
Returns the credential’s sub field element.
Sourcepub const fn issuer_schema_id(&self) -> u64
pub const fn issuer_schema_id(&self) -> u64
Returns the credential’s issuer schema ID.
Sourceimpl Credential
impl Credential
Sourcepub fn to_bytes(&self) -> Result<Vec<u8>, WalletKitError>
pub fn to_bytes(&self) -> Result<Vec<u8>, WalletKitError>
Serializes the credential to a JSON byte blob for storage.
Errors
Returns an error if serialization fails.
Sourcepub const fn genesis_issued_at(&self) -> u64
pub const fn genesis_issued_at(&self) -> u64
Returns the credential’s genesis_issued_at timestamp.
Methods from Deref<Target = CoreCredential>
pub const MAX_CLAIMS: usize = 16
Sourcepub fn get_cred_ds(&self) -> FieldElement
pub fn get_cred_ds(&self) -> FieldElement
Get the credential domain separator for the given version.
Sourcepub fn claims_hash(&self) -> Result<FieldElement, Report>
pub fn claims_hash(&self) -> Result<FieldElement, Report>
Get the claims hash of the credential.
Errors
Will error if there are more claims than the maximum allowed. Will error if the claims cannot be lowered into the field. Should not occur in practice.
Sourcepub fn hash(&self) -> Result<FieldElement, Report>
pub fn hash(&self) -> Result<FieldElement, Report>
The hash is signed by the issuer to provide authenticity for the credential.
Errors
- Will error if there are more claims than the maximum allowed.
- Will error if the claims cannot be lowered into the field. Should not occur in practice.
Sourcepub fn verify_signature(
&self,
expected_issuer_pubkey: &EdDSAPublicKey,
) -> Result<bool, Report>
pub fn verify_signature( &self, expected_issuer_pubkey: &EdDSAPublicKey, ) -> Result<bool, Report>
Verify the signature of the credential against the issuer public key and expected hash.
Errors
Will error if the credential is not signed. Will error if the credential cannot be hashed.